@@ -1,3 +1,4 @@
+# -*- coding: future_annotations -*-
 # (C) Copyright 2012-2019 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
@@ -6,11 +7,15 @@
 # granted to it by virtue of its status as an intergovernmental organisation nor
 # does it submit to any jurisdiction.
 
+# from __future__ import annotations # see PEP 563, python 3.7+
+from typing import TYPE_CHECKING # see PEP 563, python 3.7+
+if TYPE_CHECKING:
+    from skinnywms.datatypes import Availability, Plotter, Styler
+
 import logging
 import os
 import tempfile
 
-
 from skinnywms import errors, protocol
 
 LOG = logging.getLogger(__name__)
@@ -57,7 +62,7 @@ class NoCaching:
 
 
 class WMSServer:
-    def __init__(self, availability, plotter, styler, caching=NoCaching()):
+    def __init__(self, availability:Availability, plotter:Plotter, styler:Styler, caching=NoCaching()):
 
         self.availability = availability
         self.availability.set_context(self)
@@ -239,6 +244,7 @@ class WMSServer:
         width=600,
         exceptions=None,
         transparent=True,
+        legend_title_position_ratio=50.0,
     ):
 
         time = None
@@ -258,6 +264,7 @@ class WMSServer:
             version,
             width,
             transparent,
+            legend_title_position_ratio,
         )
 
         return format, path
